import { Client, Events, GatewayIntentBits, Guild, Interaction } from "discord.js"
import { utilities } from "./utilties"
import { commands } from "./commands"
import { config } from "./config"

const client : Client = new Client({
    intents: [
        GatewayIntentBits.Guilds,
        GatewayIntentBits.GuildMessages,
        GatewayIntentBits.DirectMessages
    ]
})

if (config.DB_MODE == "sqlite") {
    const db = new utilities.sqlite.SqliteDB("breadbot_test.db")

    db.run("PRAGMA foreign_keys = ON")

    utilities.tables.makeTables(db)
}

client.once(Events.ClientReady, () => {
    // TODO Winston should handle this
    console.log("Breadbot is ready")

    client.guilds.cache.forEach(async (guild: Guild) => {
        console.log(`ID: ${guild.id}, Name: ${guild.name}, Desc: ${guild.description}`)
        await utilities.command.deployCommands(guild.id)
    })
})

client.on(Events.GuildCreate, async (guild : Guild) => {
    await utilities.command.deployCommands(guild.id)
})

client.on(Events.InteractionCreate, async (interaction: Interaction) => {
    if (!interaction.isCommand()) {
        return
    }

    if (commands[interaction.commandName as keyof typeof commands]) {
        commands[interaction.commandName as keyof typeof commands].execute(interaction)
    }
})

client.login(config.DISCORD_TOKEN)